> :mag_right: parse blockchain data in search of threat indicators.

This project was first meant to enable [Forta network of detection bots][forta-explorer].

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Development](#development)
  - [Changelog](#changelog)
  - [Todo](#todo)
- [Credits](#credits)
- [License](#license)

## Installation

## Usage

## Development

Contributions welcome!

### Changelog

See [CHANGELOG](CHANGELOG.md).

### Todo

See [TODO](TODO.md).

## Credits

The metamorphic indicators were inspired by [the tool from a16z][github-a16z] and [the API by 0age][github-0age].

## License

Licensed under the [aGPL v3](LICENSE).

[forta-explorer]: https://explorer.forta.network/
[github-a16z]: https://github.com/a16z/metamorphic-contract-detector
[github-0age]: https://github.com/0age/metamorphic
